Mutation
========

.. currentmodule:: semra.pipeline

.. autoclass:: Mutation
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Mutation.model_computed_fields
      ~Mutation.model_config
      ~Mutation.model_fields

   .. rubric:: Attributes Documentation

   .. autoattribute:: model_computed_fields
   .. autoattribute:: model_config
   .. autoattribute:: model_fields
